@@ -218,20 +218,20 @@ class dti_reset_index_tz(object):
         self.df.reset_index()
 
 
-class period_setitem(object):
+class datetime_algorithm(object):
     goal_time = 0.2
 
     def setup(self):
-        self.N = 100000
-        self.rng = date_range(start='1/1/2000', periods=self.N, freq='T')
-        if hasattr(Series, 'convert'):
-            Series.resample = Series.convert
-        self.ts = Series(np.random.randn(self.N), index=self.rng)
-        self.rng = period_range(start='1/1/1990', freq='S', periods=20000)
-        self.df = DataFrame(index=range(len(self.rng)))
+        N = 100000
+        self.dti = pd.date_range('2011-01-01', freq='H', periods=N).repeat(5)
+        self.dti_tz = pd.date_range('2011-01-01', freq='H', periods=N,
+                                    tz='Asia/Tokyo').repeat(5)
 
-    def time_period_setitem(self):
-        self.df['col'] = self.rng
+    def time_dti_factorize(self):
+        self.dti.factorize()
+
+    def time_dti_tz_factorize(self):
+        self.dti_tz.factorize()
 
 
 class timeseries_1min_5min_mean(object):
@@ -284,56 +284,77 @@ class timeseries_asof(object):
     goal_time = 0.2
 
     def setup(self):
-        self.N = 100000
-        self.rng = date_range(start='1/1/2000', periods=self.N, freq='T')
-        if hasattr(Series, 'convert'):
-            Series.resample = Series.convert
-        self.ts = Series(np.random.randn(self.N), index=self.rng)
         self.N = 10000
         self.rng = date_range(start='1/1/1990', periods=self.N, freq='53s')
-        self.ts = Series(np.random.randn(self.N), index=self.rng)
         self.dates = date_range(start='1/1/1990', periods=(self.N * 10), freq='5s')
+        self.ts = Series(np.random.randn(self.N), index=self.rng)
+        self.ts2 = self.ts.copy()
+        self.ts2[250:5000] = np.nan
+        self.ts3 = self.ts.copy()
+        self.ts3[-5000:] = np.nan
 
-    def time_timeseries_asof(self):
+    # test speed of pre-computing NAs.
+    def time_asof_list(self):
         self.ts.asof(self.dates)
 
+    # should be roughly the same as above.
+    def time_asof_nan_list(self):
+        self.ts2.asof(self.dates)
 
-class timeseries_asof_nan(object):
-    goal_time = 0.2
-
-    def setup(self):
-        self.N = 100000
-        self.rng = date_range(start='1/1/2000', periods=self.N, freq='T')
-        if hasattr(Series, 'convert'):
-            Series.resample = Series.convert
-        self.ts = Series(np.random.randn(self.N), index=self.rng)
-        self.N = 10000
-        self.rng = date_range(start='1/1/1990', periods=self.N, freq='53s')
-        self.ts = Series(np.random.randn(self.N), index=self.rng)
-        self.dates = date_range(start='1/1/1990', periods=(self.N * 10), freq='5s')
-        self.ts[250:5000] = np.nan
-
-    def time_timeseries_asof_nan(self):
-        self.ts.asof(self.dates)
-
-
-class timeseries_asof_single(object):
-    goal_time = 0.2
-
-    def setup(self):
-        self.N = 100000
-        self.rng = date_range(start='1/1/2000', periods=self.N, freq='T')
-        if hasattr(Series, 'convert'):
-            Series.resample = Series.convert
-        self.ts = Series(np.random.randn(self.N), index=self.rng)
-        self.N = 10000
-        self.rng = date_range(start='1/1/1990', periods=self.N, freq='53s')
-        self.ts = Series(np.random.randn(self.N), index=self.rng)
-        self.dates = date_range(start='1/1/1990', periods=(self.N * 10), freq='5s')
-
-    def time_timeseries_asof_single(self):
+    # test speed of the code path for a scalar index
+    # without *while* loop
+    def time_asof_single(self):
         self.ts.asof(self.dates[0])
 
+    # test speed of the code path for a scalar index
+    # before the start. should be the same as above.
+    def time_asof_single_early(self):
+        self.ts.asof(self.dates[0] - dt.timedelta(10))
+
+    # test the speed of the code path for a scalar index
+    # with a long *while* loop. should still be much
+    # faster than pre-computing all the NAs.
+    def time_asof_nan_single(self):
+        self.ts3.asof(self.dates[-1])
+
+
+class timeseries_dataframe_asof(object):
+    goal_time = 0.2
+
+    def setup(self):
+        self.N = 10000
+        self.M = 100
+        self.rng = date_range(start='1/1/1990', periods=self.N, freq='53s')
+        self.dates = date_range(start='1/1/1990', periods=(self.N * 10), freq='5s')
+        self.ts = DataFrame(np.random.randn(self.N, self.M), index=self.rng)
+        self.ts2 = self.ts.copy()
+        self.ts2.iloc[250:5000] = np.nan
+        self.ts3 = self.ts.copy()
+        self.ts3.iloc[-5000:] = np.nan
+
+    # test speed of pre-computing NAs.
+    def time_asof_list(self):
+        self.ts.asof(self.dates)
+
+    # should be roughly the same as above.
+    def time_asof_nan_list(self):
+        self.ts2.asof(self.dates)
+
+    # test speed of the code path for a scalar index
+    # with pre-computing all NAs.
+    def time_asof_single(self):
+        self.ts.asof(self.dates[0])
+
+    # should be roughly the same as above.
+    def time_asof_nan_single(self):
+        self.ts3.asof(self.dates[-1])
+
+    # test speed of the code path for a scalar index
+    # before the start. should be without the cost of
+    # pre-computing all the NAs.
+    def time_asof_single_early(self):
+        self.ts.asof(self.dates[0] - dt.timedelta(10))
+
 
 class timeseries_custom_bday_apply(object):
     goal_time = 0.2
@@ -1155,3 +1176,63 @@ class timeseries_year_incr(object):
 
     def time_timeseries_year_incr(self):
         (self.date + self.year)
+
+
+class timeseries_semi_month_offset(object):
+    goal_time = 0.2
+
+    def setup(self):
+        self.N = 100000
+        self.rng = date_range(start='1/1/2000', periods=self.N, freq='T')
+        # date is not on an offset which will be slowest case
+        self.date = dt.datetime(2011, 1, 2)
+        self.semi_month_end = pd.offsets.SemiMonthEnd()
+        self.semi_month_begin = pd.offsets.SemiMonthBegin()
+
+    def time_semi_month_end_apply(self):
+        self.semi_month_end.apply(self.date)
+
+    def time_semi_month_end_incr(self):
+        self.date + self.semi_month_end
+
+    def time_semi_month_end_incr_n(self):
+        self.date + 10 * self.semi_month_end
+
+    def time_semi_month_end_decr(self):
+        self.date - self.semi_month_end
+
+    def time_semi_month_end_decr_n(self):
+        self.date - 10 * self.semi_month_end
+
+    def time_semi_month_end_apply_index(self):
+        self.semi_month_end.apply_index(self.rng)
+
+    def time_semi_month_end_incr_rng(self):
+        self.rng + self.semi_month_end
+
+    def time_semi_month_end_decr_rng(self):
+        self.rng - self.semi_month_end
+
+    def time_semi_month_begin_apply(self):
+        self.semi_month_begin.apply(self.date)
+
+    def time_semi_month_begin_incr(self):
+        self.date + self.semi_month_begin
+
+    def time_semi_month_begin_incr_n(self):
+        self.date + 10 * self.semi_month_begin
+
+    def time_semi_month_begin_decr(self):
+        self.date - self.semi_month_begin
+
+    def time_semi_month_begin_decr_n(self):
+        self.date - 10 * self.semi_month_begin
+
+    def time_semi_month_begin_apply_index(self):
+        self.semi_month_begin.apply_index(self.rng)
+
+    def time_semi_month_begin_incr_rng(self):
+        self.rng + self.semi_month_begin
+
+    def time_semi_month_begin_decr_rng(self):
+        self.rng - self.semi_month_begin
