@@ -31,10 +31,7 @@ edit_init
 home_dir=$(pwd)
 echo "home_dir: [$home_dir]"
 
-python_major_version="${TRAVIS_PYTHON_VERSION:0:1}"
-[ "$python_major_version" == "2" ] && python_major_version=""
-
-MINICONDA_DIR="$HOME/miniconda"
+MINICONDA_DIR="$HOME/miniconda3"
 
 if [ -d "$MINICONDA_DIR" ] && [ -e "$MINICONDA_DIR/bin/conda" ] && [ "$USE_CACHE" ]; then
     echo "Miniconda install already present from cache: $MINICONDA_DIR"
@@ -63,9 +60,9 @@ else
     rm -rf "$MINICONDA_DIR"
     # install miniconda
     if [ "${TRAVIS_OS_NAME}" == "osx" ]; then
-        wget http://repo.continuum.io/miniconda/Miniconda-latest-MacOSX-x86_64.sh -O miniconda.sh || exit 1
+        wget http://repo.continuum.io/miniconda/Miniconda3-latest-MacOSX-x86_64.sh -O miniconda.sh || exit 1
     else
-        wget http://repo.continuum.io/miniconda/Miniconda-latest-Linux-x86_64.sh -O miniconda.sh || exit 1
+        wget http://repo.continuum.io/miniconda/Miniconda3-latest-Linux-x86_64.sh -O miniconda.sh || exit 1
     fi
     bash miniconda.sh -b -p "$MINICONDA_DIR" || exit 1
 
@@ -84,21 +81,25 @@ else
 
     # Useful for debugging any issues with conda
     conda info -a || exit 1
-
-    time conda create -n pandas python=$TRAVIS_PYTHON_VERSION nose coverage flake8 || exit 1
-
 fi
-# build deps
-REQ="ci/requirements-${TRAVIS_PYTHON_VERSION}${JOB_TAG}.build"
 
-# may have additional installation instructions for this build
-INSTALL="ci/install-${TRAVIS_PYTHON_VERSION}${JOB_TAG}.sh"
+# may have installation instructions for this build
+INSTALL="ci/install-${PYTHON_VERSION}${JOB_TAG}.sh"
 if [ -e ${INSTALL} ]; then
     time bash $INSTALL || exit 1
+else
+
+    # create new env
+    time conda create -n pandas python=$PYTHON_VERSION nose coverage flake8 || exit 1
 fi
 
+# build deps
+REQ="ci/requirements-${PYTHON_VERSION}${JOB_TAG}.build"
+
 # install deps
-time conda install -n pandas --file=${REQ} || exit 1
+if [ -e ${REQ} ]; then
+    time conda install -n pandas --file=${REQ} || exit 1
+fi
 
 source activate pandas
 
@@ -106,7 +107,7 @@ if [ "$BUILD_TEST" ]; then
 
     # build testing
     pip uninstall --yes cython
-    pip install cython==0.15.1
+    pip install cython==0.19.1
     ( python setup.py build_ext --inplace && python setup.py develop ) || true
 
 else
@@ -117,14 +118,22 @@ else
 
     # we may have run installations
     echo "conda installs"
-    REQ="ci/requirements-${TRAVIS_PYTHON_VERSION}${JOB_TAG}.run"
-    time conda install -n pandas --file=${REQ} || exit 1
+    REQ="ci/requirements-${PYTHON_VERSION}${JOB_TAG}.run"
+    if [ -e ${REQ} ]; then
+        time conda install -n pandas --file=${REQ} || exit 1
+    fi
 
     # we may have additional pip installs
     echo "pip installs"
-    REQ="ci/requirements-${TRAVIS_PYTHON_VERSION}${JOB_TAG}.pip"
+    REQ="ci/requirements-${PYTHON_VERSION}${JOB_TAG}.pip"
     if [ -e ${REQ} ]; then
-        pip install --upgrade -r $REQ
+       pip install --upgrade -r $REQ
+    fi
+
+    # may have addtl installation instructions for this build
+    REQ="ci/requirements-${PYTHON_VERSION}${JOB_TAG}.sh"
+    if [ -e ${REQ} ]; then
+        time bash $REQ || exit 1
     fi
 
     # remove any installed pandas package
@@ -138,9 +147,5 @@ else
 
 fi
 
-if [ "$JOB_NAME" == "34_slow" ]; then
-    conda install -c conda-forge/label/rc -c conda-forge matplotlib
-fi
-
 echo "done"
 exit 0
