@@ -4,6 +4,8 @@ Ordinary least squares regression
 
 # pylint: disable-msg=W0201
 
+# flake8: noqa
+
 from pandas.compat import zip, range, StringIO
 from itertools import starmap
 from pandas import compat
@@ -11,7 +13,7 @@ import numpy as np
 
 from pandas.core.api import DataFrame, Series, isnull
 from pandas.core.base import StringMixin
-from pandas.core.common import _ensure_float64
+from pandas.types.common import _ensure_float64
 from pandas.core.index import MultiIndex
 from pandas.core.panel import Panel
 from pandas.util.decorators import cache_readonly
@@ -22,7 +24,6 @@ import pandas.stats.moments as moments
 
 _FP_ERR = 1e-8
 
-
 class OLS(StringMixin):
     """
     Runs a full sample ordinary least squares regression.
@@ -47,6 +48,13 @@ class OLS(StringMixin):
 
     def __init__(self, y, x, intercept=True, weights=None, nw_lags=None,
                  nw_overlap=False):
+        import warnings
+        warnings.warn("The pandas.stats.ols module is deprecated and will be "
+                      "removed in a future version. We refer to external packages "
+                      "like statsmodels, see some examples here: "
+                      "http://www.statsmodels.org/stable/regression.html",
+                      FutureWarning, stacklevel=4)
+
         try:
             import statsmodels.api as sm
         except ImportError:
@@ -97,7 +105,7 @@ class OLS(StringMixin):
             filt_rhs['intercept'] = 1.
             pre_filt_rhs['intercept'] = 1.
 
-        if hasattr(filt_weights,'to_dense'):
+        if hasattr(filt_weights, 'to_dense'):
             filt_weights = filt_weights.to_dense()
 
         return (filt_lhs, filt_rhs, filt_weights,
@@ -614,7 +622,8 @@ class MovingOLS(OLS):
         size of window (for rolling/expanding OLS)
     min_periods : int
         Threshold of non-null data points to require.
-        If None, defaults to size of window.
+        If None, defaults to size of window for window_type='rolling' and 1
+        otherwise
     intercept : bool
         True if you want an intercept.
     nw_lags : None or int
@@ -623,6 +632,7 @@ class MovingOLS(OLS):
         Assume data is overlapping when computing Newey-West estimator
 
     """
+
     def __init__(self, y, x, weights=None, window_type='expanding',
                  window=None, min_periods=None, intercept=True,
                  nw_lags=None, nw_overlap=False):
@@ -818,7 +828,7 @@ class MovingOLS(OLS):
 
             betas[i] = math.solve(xx, xy)
 
-        mask = -np.isnan(betas).any(axis=1)
+        mask = ~np.isnan(betas).any(axis=1)
         have_betas = np.arange(N)[mask]
 
         return betas, have_betas, mask
@@ -982,7 +992,7 @@ class MovingOLS(OLS):
 
         result = [2 * t.sf(a, b)
                   for a, b in zip(np.fabs(self._t_stat_raw),
-                                   self._df_resid_raw)]
+                                  self._df_resid_raw)]
 
         return np.array(result)
 
@@ -1196,8 +1206,11 @@ class MovingOLS(OLS):
 
     @cache_readonly
     def _window_time_obs(self):
-        window_obs = moments.rolling_sum(self._time_obs_count > 0,
-                                         self._window, min_periods=1)
+        window_obs = (Series(self._time_obs_count > 0)
+                      .rolling(self._window, min_periods=1)
+                      .sum()
+                      .values
+                      )
 
         window_obs[np.isnan(window_obs)] = 0
         return window_obs.astype(int)
@@ -1210,8 +1223,8 @@ class MovingOLS(OLS):
             # expanding case
             window = len(self._index)
 
-        result = moments.rolling_sum(self._time_obs_count, window,
-                                     min_periods=1)
+        result = Series(self._time_obs_count).rolling(
+            window, min_periods=1).sum().values
 
         return result.astype(int)
 
@@ -1305,7 +1318,7 @@ def _filter_data(lhs, rhs, weights=None):
     filt_lhs = combined.pop('__y__')
     filt_rhs = combined
 
-    if hasattr(filt_weights,'to_dense'):
+    if hasattr(filt_weights, 'to_dense'):
         filt_weights = filt_weights.to_dense()
 
     return (filt_lhs.to_dense(), filt_rhs.to_dense(), filt_weights,
