@@ -9,42 +9,49 @@ from numpy.random import randn
 
 import operator
 import numpy as np
-from numpy.testing import assert_array_equal
 
 from pandas.core.api import DataFrame, Panel
 from pandas.computation import expressions as expr
 from pandas import compat
-
 from pandas.util.testing import (assert_almost_equal, assert_series_equal,
                                  assert_frame_equal, assert_panel_equal,
-                                 assert_panel4d_equal)
+                                 assert_panel4d_equal, slow)
+from pandas.formats.printing import pprint_thing
 import pandas.util.testing as tm
-from numpy.testing.decorators import slow
 
 
 if not expr._USE_NUMEXPR:
     try:
-        import numexpr
+        import numexpr  # noqa
     except ImportError:
         msg = "don't have"
     else:
         msg = "not using"
     raise nose.SkipTest("{0} numexpr".format(msg))
 
-_frame  = DataFrame(randn(10000, 4), columns=list('ABCD'), dtype='float64')
-_frame2 = DataFrame(randn(100, 4),   columns = list('ABCD'), dtype='float64')
-_mixed  = DataFrame({ 'A' : _frame['A'].copy(), 'B' : _frame['B'].astype('float32'), 'C' : _frame['C'].astype('int64'), 'D' : _frame['D'].astype('int32') })
-_mixed2 = DataFrame({ 'A' : _frame2['A'].copy(), 'B' : _frame2['B'].astype('float32'), 'C' : _frame2['C'].astype('int64'), 'D' : _frame2['D'].astype('int32') })
-_integer  = DataFrame(np.random.randint(1, 100, size=(10001, 4)), columns = list('ABCD'), dtype='int64')
+_frame = DataFrame(randn(10000, 4), columns=list('ABCD'), dtype='float64')
+_frame2 = DataFrame(randn(100, 4), columns=list('ABCD'), dtype='float64')
+_mixed = DataFrame({'A': _frame['A'].copy(),
+                    'B': _frame['B'].astype('float32'),
+                    'C': _frame['C'].astype('int64'),
+                    'D': _frame['D'].astype('int32')})
+_mixed2 = DataFrame({'A': _frame2['A'].copy(),
+                     'B': _frame2['B'].astype('float32'),
+                     'C': _frame2['C'].astype('int64'),
+                     'D': _frame2['D'].astype('int32')})
+_integer = DataFrame(
+    np.random.randint(1, 100,
+                      size=(10001, 4)), columns=list('ABCD'), dtype='int64')
 _integer2 = DataFrame(np.random.randint(1, 100, size=(101, 4)),
                       columns=list('ABCD'), dtype='int64')
-_frame_panel = Panel(dict(ItemA=_frame.copy(), ItemB=(_frame.copy() + 3), ItemC=_frame.copy(), ItemD=_frame.copy()))
+_frame_panel = Panel(dict(ItemA=_frame.copy(), ItemB=(
+    _frame.copy() + 3), ItemC=_frame.copy(), ItemD=_frame.copy()))
 _frame2_panel = Panel(dict(ItemA=_frame2.copy(), ItemB=(_frame2.copy() + 3),
                            ItemC=_frame2.copy(), ItemD=_frame2.copy()))
-_integer_panel = Panel(dict(ItemA=_integer,
-                            ItemB=(_integer + 34).astype('int64')))
-_integer2_panel = Panel(dict(ItemA=_integer2,
-                             ItemB=(_integer2 + 34).astype('int64')))
+_integer_panel = Panel(dict(ItemA=_integer, ItemB=(_integer + 34).astype(
+    'int64')))
+_integer2_panel = Panel(dict(ItemA=_integer2, ItemB=(_integer2 + 34).astype(
+    'int64')))
 _mixed_panel = Panel(dict(ItemA=_mixed, ItemB=(_mixed + 3)))
 _mixed2_panel = Panel(dict(ItemA=_mixed2, ItemB=(_mixed2 + 3)))
 
@@ -55,9 +62,9 @@ class TestExpressions(tm.TestCase):
 
     def setUp(self):
 
-        self.frame  = _frame.copy()
+        self.frame = _frame.copy()
         self.frame2 = _frame2.copy()
-        self.mixed  = _mixed.copy()
+        self.mixed = _mixed.copy()
         self.mixed2 = _mixed2.copy()
         self.integer = _integer.copy()
         self._MIN_ELEMENTS = expr._MIN_ELEMENTS
@@ -92,19 +99,19 @@ class TestExpressions(tm.TestCase):
                         assert expected.dtype.kind == 'f'
                 assert_func(expected, result)
             except Exception:
-                com.pprint_thing("Failed test with operator %r" % op.__name__)
+                pprint_thing("Failed test with operator %r" % op.__name__)
                 raise
 
     def test_integer_arithmetic(self):
         self.run_arithmetic_test(self.integer, self.integer,
                                  assert_frame_equal)
-        self.run_arithmetic_test(self.integer.icol(0), self.integer.icol(0),
-                                 assert_series_equal, check_dtype=True)
+        self.run_arithmetic_test(self.integer.iloc[:, 0],
+                                 self.integer.iloc[:, 0], assert_series_equal,
+                                 check_dtype=True)
 
     @nose.tools.nottest
-    def run_binary_test(self, df, other, assert_func,
-                        test_flex=False, numexpr_ops=set(['gt', 'lt', 'ge',
-                                                          'le', 'eq', 'ne'])):
+    def run_binary_test(self, df, other, assert_func, test_flex=False,
+                        numexpr_ops=set(['gt', 'lt', 'ge', 'le', 'eq', 'ne'])):
         """
         tests solely that the result is the same whether or not numexpr is
         enabled.  Need to test whether the function does the correct thing
@@ -132,8 +139,8 @@ class TestExpressions(tm.TestCase):
                     assert not used_numexpr, "Used numexpr unexpectedly."
                 assert_func(expected, result)
             except Exception:
-                com.pprint_thing("Failed test with operation %r" % arith)
-                com.pprint_thing("test_flex was %r" % test_flex)
+                pprint_thing("Failed test with operation %r" % arith)
+                pprint_thing("test_flex was %r" % test_flex)
                 raise
 
     def run_frame(self, df, other, binary_comp=None, run_binary=True,
@@ -160,10 +167,10 @@ class TestExpressions(tm.TestCase):
         # series doesn't uses vec_compare instead of numexpr...
         # if binary_comp is None:
         #     binary_comp = other + 1
-        # self.run_binary_test(ser, binary_comp, assert_frame_equal, test_flex=False,
-        #         **kwargs)
-        # self.run_binary_test(ser, binary_comp, assert_frame_equal, test_flex=True,
-        #         **kwargs)
+        # self.run_binary_test(ser, binary_comp, assert_frame_equal,
+        # test_flex=False, **kwargs)
+        # self.run_binary_test(ser, binary_comp, assert_frame_equal,
+        # test_flex=True, **kwargs)
 
     def run_panel(self, panel, other, binary_comp=None, run_binary=True,
                   assert_func=assert_panel_equal, **kwargs):
@@ -183,7 +190,7 @@ class TestExpressions(tm.TestCase):
         self.run_frame(self.integer, self.integer)
 
     def test_integer_arithmetic_series(self):
-        self.run_series(self.integer.icol(0), self.integer.icol(0))
+        self.run_series(self.integer.iloc[:, 0], self.integer.iloc[:, 0])
 
     @slow
     def test_integer_panel(self):
@@ -193,7 +200,7 @@ class TestExpressions(tm.TestCase):
         self.run_frame(self.frame2, self.frame2)
 
     def test_float_arithmetic_series(self):
-        self.run_series(self.frame2.icol(0), self.frame2.icol(0))
+        self.run_series(self.frame2.iloc[:, 0], self.frame2.iloc[:, 0])
 
     @slow
     def test_float_panel(self):
@@ -201,8 +208,9 @@ class TestExpressions(tm.TestCase):
 
     @slow
     def test_panel4d(self):
-        self.run_panel(tm.makePanel4D(), np.random.randn() + 0.5,
-                       assert_func=assert_panel4d_equal, binary_comp=3)
+        with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
+            self.run_panel(tm.makePanel4D(), np.random.randn() + 0.5,
+                           assert_func=assert_panel4d_equal, binary_comp=3)
 
     def test_mixed_arithmetic_frame(self):
         # TODO: FIGURE OUT HOW TO GET IT TO WORK...
@@ -221,7 +229,7 @@ class TestExpressions(tm.TestCase):
 
     def test_float_arithemtic(self):
         self.run_arithmetic_test(self.frame, self.frame, assert_frame_equal)
-        self.run_arithmetic_test(self.frame.icol(0), self.frame.icol(0),
+        self.run_arithmetic_test(self.frame.iloc[:, 0], self.frame.iloc[:, 0],
                                  assert_series_equal, check_dtype=True)
 
     def test_mixed_arithmetic(self):
@@ -232,51 +240,65 @@ class TestExpressions(tm.TestCase):
 
     def test_integer_with_zeros(self):
         self.integer *= np.random.randint(0, 2, size=np.shape(self.integer))
-        self.run_arithmetic_test(self.integer, self.integer, assert_frame_equal)
-        self.run_arithmetic_test(self.integer.icol(0), self.integer.icol(0),
-                                 assert_series_equal)
+        self.run_arithmetic_test(self.integer, self.integer,
+                                 assert_frame_equal)
+        self.run_arithmetic_test(self.integer.iloc[:, 0],
+                                 self.integer.iloc[:, 0], assert_series_equal)
 
     def test_invalid(self):
 
         # no op
-        result   = expr._can_use_numexpr(operator.add, None, self.frame, self.frame, 'evaluate')
+        result = expr._can_use_numexpr(operator.add, None, self.frame,
+                                       self.frame, 'evaluate')
         self.assertFalse(result)
 
         # mixed
-        result   = expr._can_use_numexpr(operator.add, '+', self.mixed, self.frame, 'evaluate')
+        result = expr._can_use_numexpr(operator.add, '+', self.mixed,
+                                       self.frame, 'evaluate')
         self.assertFalse(result)
 
         # min elements
-        result   = expr._can_use_numexpr(operator.add, '+', self.frame2, self.frame2, 'evaluate')
+        result = expr._can_use_numexpr(operator.add, '+', self.frame2,
+                                       self.frame2, 'evaluate')
         self.assertFalse(result)
 
         # ok, we only check on first part of expression
-        result   = expr._can_use_numexpr(operator.add, '+', self.frame, self.frame2, 'evaluate')
+        result = expr._can_use_numexpr(operator.add, '+', self.frame,
+                                       self.frame2, 'evaluate')
         self.assertTrue(result)
 
     def test_binary_ops(self):
-
         def testit():
 
-            for f, f2 in [ (self.frame, self.frame2), (self.mixed, self.mixed2) ]:
+            for f, f2 in [(self.frame, self.frame2),
+                          (self.mixed, self.mixed2)]:
 
-                for op, op_str in [('add','+'),('sub','-'),('mul','*'),('div','/'),('pow','**')]:
+                for op, op_str in [('add', '+'), ('sub', '-'), ('mul', '*'),
+                                   ('div', '/'), ('pow', '**')]:
                     if op == 'div':
                         op = getattr(operator, 'truediv', None)
                     else:
                         op = getattr(operator, op, None)
                     if op is not None:
-                        result   = expr._can_use_numexpr(op, op_str, f, f, 'evaluate')
+                        result = expr._can_use_numexpr(op, op_str, f, f,
+                                                       'evaluate')
                         self.assertNotEqual(result, f._is_mixed_type)
 
-                        result   = expr.evaluate(op, op_str, f, f, use_numexpr=True)
-                        expected = expr.evaluate(op, op_str, f, f, use_numexpr=False)
-                        assert_array_equal(result,expected.values)
+                        result = expr.evaluate(op, op_str, f, f,
+                                               use_numexpr=True)
+                        expected = expr.evaluate(op, op_str, f, f,
+                                                 use_numexpr=False)
 
-                        result   = expr._can_use_numexpr(op, op_str, f2, f2, 'evaluate')
+                        if isinstance(result, DataFrame):
+                            tm.assert_frame_equal(result, expected)
+                        else:
+                            tm.assert_numpy_array_equal(result,
+                                                        expected.values)
+
+                        result = expr._can_use_numexpr(op, op_str, f2, f2,
+                                                       'evaluate')
                         self.assertFalse(result)
 
-
         expr.set_use_numexpr(False)
         testit()
         expr.set_use_numexpr(True)
@@ -286,10 +308,9 @@ class TestExpressions(tm.TestCase):
         testit()
 
     def test_boolean_ops(self):
-
-
         def testit():
-            for f, f2 in [ (self.frame, self.frame2), (self.mixed, self.mixed2) ]:
+            for f, f2 in [(self.frame, self.frame2),
+                          (self.mixed, self.mixed2)]:
 
                 f11 = f
                 f12 = f + 1
@@ -297,18 +318,26 @@ class TestExpressions(tm.TestCase):
                 f21 = f2
                 f22 = f2 + 1
 
-                for op, op_str in [('gt','>'),('lt','<'),('ge','>='),('le','<='),('eq','=='),('ne','!=')]:
+                for op, op_str in [('gt', '>'), ('lt', '<'), ('ge', '>='),
+                                   ('le', '<='), ('eq', '=='), ('ne', '!=')]:
 
-                    op = getattr(operator,op)
+                    op = getattr(operator, op)
 
-                    result   = expr._can_use_numexpr(op, op_str, f11, f12, 'evaluate')
+                    result = expr._can_use_numexpr(op, op_str, f11, f12,
+                                                   'evaluate')
                     self.assertNotEqual(result, f11._is_mixed_type)
 
-                    result   = expr.evaluate(op, op_str, f11, f12, use_numexpr=True)
-                    expected = expr.evaluate(op, op_str, f11, f12, use_numexpr=False)
-                    assert_array_equal(result,expected.values)
+                    result = expr.evaluate(op, op_str, f11, f12,
+                                           use_numexpr=True)
+                    expected = expr.evaluate(op, op_str, f11, f12,
+                                             use_numexpr=False)
+                    if isinstance(result, DataFrame):
+                        tm.assert_frame_equal(result, expected)
+                    else:
+                        tm.assert_numpy_array_equal(result, expected.values)
 
-                    result   = expr._can_use_numexpr(op, op_str, f21, f22, 'evaluate')
+                    result = expr._can_use_numexpr(op, op_str, f21, f22,
+                                                   'evaluate')
                     self.assertFalse(result)
 
         expr.set_use_numexpr(False)
@@ -320,18 +349,16 @@ class TestExpressions(tm.TestCase):
         testit()
 
     def test_where(self):
-
         def testit():
-            for f in [ self.frame, self.frame2, self.mixed, self.mixed2 ]:
+            for f in [self.frame, self.frame2, self.mixed, self.mixed2]:
 
+                for cond in [True, False]:
 
-                for cond in [ True, False ]:
-
-                    c = np.empty(f.shape,dtype=np.bool_)
+                    c = np.empty(f.shape, dtype=np.bool_)
                     c.fill(cond)
-                    result   = expr.where(c, f.values, f.values+1)
-                    expected = np.where(c, f.values, f.values+1)
-                    assert_array_equal(result,expected)
+                    result = expr.where(c, f.values, f.values + 1)
+                    expected = np.where(c, f.values, f.values + 1)
+                    tm.assert_numpy_array_equal(result, expected)
 
         expr.set_use_numexpr(False)
         testit()
@@ -383,32 +410,32 @@ class TestExpressions(tm.TestCase):
             fe = getattr(operator, sub_funcs[subs[op]])
 
             with tm.use_numexpr(True, min_elements=5):
-                with tm.assert_produces_warning():
+                with tm.assert_produces_warning(check_stacklevel=False):
                     r = f(df, df)
                     e = fe(df, df)
                     tm.assert_frame_equal(r, e)
 
-                with tm.assert_produces_warning():
+                with tm.assert_produces_warning(check_stacklevel=False):
                     r = f(df.a, df.b)
                     e = fe(df.a, df.b)
                     tm.assert_series_equal(r, e)
 
-                with tm.assert_produces_warning():
+                with tm.assert_produces_warning(check_stacklevel=False):
                     r = f(df.a, True)
                     e = fe(df.a, True)
                     tm.assert_series_equal(r, e)
 
-                with tm.assert_produces_warning():
+                with tm.assert_produces_warning(check_stacklevel=False):
                     r = f(False, df.a)
                     e = fe(False, df.a)
                     tm.assert_series_equal(r, e)
 
-                with tm.assert_produces_warning():
+                with tm.assert_produces_warning(check_stacklevel=False):
                     r = f(False, df)
                     e = fe(False, df)
                     tm.assert_frame_equal(r, e)
 
-                with tm.assert_produces_warning():
+                with tm.assert_produces_warning(check_stacklevel=False):
                     r = f(df, True)
                     e = fe(df, True)
                     tm.assert_frame_equal(r, e)
