@@ -2,11 +2,13 @@
 Quantilization functions and related stuff
 """
 
-from pandas.core.api import DataFrame, Series
+from pandas.types.missing import isnull
+from pandas.types.common import (is_float, is_integer,
+                                 is_scalar)
+
+from pandas.core.api import Series
 from pandas.core.categorical import Categorical
-from pandas.core.index import _ensure_index
 import pandas.core.algorithms as algos
-import pandas.core.common as com
 import pandas.core.nanops as nanops
 from pandas.compat import zip
 
@@ -34,8 +36,9 @@ def cut(x, bins, right=True, labels=None, retbins=False, precision=3,
         right == True (the default), then the bins [1,2,3,4] indicate
         (1,2], (2,3], (3,4].
     labels : array or boolean, default None
-        Used as labels for the resulting bins. Must be of the same length as the resulting
-        bins. If False, return only integer indicators of the bins.
+        Used as labels for the resulting bins. Must be of the same length as
+        the resulting bins. If False, return only integer indicators of the
+        bins.
     retbins : bool, optional
         Whether to return the bins or not. Can be useful if bins is given
         as a scalar.
@@ -47,9 +50,9 @@ def cut(x, bins, right=True, labels=None, retbins=False, precision=3,
     Returns
     -------
     out : Categorical or Series or array of integers if labels is False
-        The return type (Categorical or Series) depends on the input: a Series of type category if
-        input is a Series else Categorical. Bins are represented as categories when categorical
-        data is returned.
+        The return type (Categorical or Series) depends on the input: a Series
+        of type category if input is a Series else Categorical. Bins are
+        represented as categories when categorical data is returned.
     bins : ndarray of floats
         Returned only if `retbins` is True.
 
@@ -66,10 +69,12 @@ def cut(x, bins, right=True, labels=None, retbins=False, precision=3,
     Examples
     --------
     >>> pd.cut(np.array([.2, 1.4, 2.5, 6.2, 9.7, 2.1]), 3, retbins=True)
-    ([(0.191, 3.367], (0.191, 3.367], (0.191, 3.367], (3.367, 6.533], (6.533, 9.7], (0.191, 3.367]]
+    ([(0.191, 3.367], (0.191, 3.367], (0.191, 3.367], (3.367, 6.533],
+      (6.533, 9.7], (0.191, 3.367]]
     Categories (3, object): [(0.191, 3.367] < (3.367, 6.533] < (6.533, 9.7]],
     array([ 0.1905    ,  3.36666667,  6.53333333,  9.7       ]))
-    >>> pd.cut(np.array([.2, 1.4, 2.5, 6.2, 9.7, 2.1]), 3, labels=["good","medium","bad"])
+    >>> pd.cut(np.array([.2, 1.4, 2.5, 6.2, 9.7, 2.1]), 3,
+               labels=["good","medium","bad"])
     [good, good, good, medium, bad, good]
     Categories (3, object): [good < medium < bad]
     >>> pd.cut(np.ones(5), 4, labels=False)
@@ -77,7 +82,7 @@ def cut(x, bins, right=True, labels=None, retbins=False, precision=3,
     """
     # NOTE: this binning code is changed a bit from histogram for var(x) == 0
     if not np.iterable(bins):
-        if np.isscalar(bins) and bins < 1:
+        if is_scalar(bins) and bins < 1:
             raise ValueError("`bins` should be a positive integer.")
         try:  # for array-like
             sz = x.size
@@ -93,8 +98,8 @@ def cut(x, bins, right=True, labels=None, retbins=False, precision=3,
         mn, mx = [mi + 0.0 for mi in rng]
 
         if mn == mx:  # adjust end points before binning
-            mn -= .001 * mn
-            mx += .001 * mx
+            mn -= .001 * abs(mn)
+            mx += .001 * abs(mx)
             bins = np.linspace(mn, mx, bins + 1, endpoint=True)
         else:  # adjust end points after binning
             bins = np.linspace(mn, mx, bins + 1, endpoint=True)
@@ -109,11 +114,11 @@ def cut(x, bins, right=True, labels=None, retbins=False, precision=3,
         if (np.diff(bins) < 0).any():
             raise ValueError('bins must increase monotonically.')
 
-    return _bins_to_cuts(x, bins, right=right, labels=labels,retbins=retbins, precision=precision,
+    return _bins_to_cuts(x, bins, right=right, labels=labels,
+                         retbins=retbins, precision=precision,
                          include_lowest=include_lowest)
 
 
-
 def qcut(x, q, labels=None, retbins=False, precision=3):
     """
     Quantile-based discretization function. Discretize variable into
@@ -128,8 +133,9 @@ def qcut(x, q, labels=None, retbins=False, precision=3):
         Number of quantiles. 10 for deciles, 4 for quartiles, etc. Alternately
         array of quantiles, e.g. [0, .25, .5, .75, 1.] for quartiles
     labels : array or boolean, default None
-        Used as labels for the resulting bins. Must be of the same length as the resulting
-        bins. If False, return only integer indicators of the bins.
+        Used as labels for the resulting bins. Must be of the same length as
+        the resulting bins. If False, return only integer indicators of the
+        bins.
     retbins : bool, optional
         Whether to return the bins or not. Can be useful if bins is given
         as a scalar.
@@ -139,9 +145,9 @@ def qcut(x, q, labels=None, retbins=False, precision=3):
     Returns
     -------
     out : Categorical or Series or array of integers if labels is False
-        The return type (Categorical or Series) depends on the input: a Series of type category if
-        input is a Series else Categorical. Bins are represented as categories when categorical
-        data is returned.
+        The return type (Categorical or Series) depends on the input: a Series
+        of type category if input is a Series else Categorical. Bins are
+        represented as categories when categorical data is returned.
     bins : ndarray of floats
         Returned only if `retbins` is True.
 
@@ -160,14 +166,13 @@ def qcut(x, q, labels=None, retbins=False, precision=3):
     >>> pd.qcut(range(5), 4, labels=False)
     array([0, 0, 1, 2, 3], dtype=int64)
     """
-    if com.is_integer(q):
+    if is_integer(q):
         quantiles = np.linspace(0, 1, q + 1)
     else:
         quantiles = q
     bins = algos.quantile(x, quantiles)
-    return _bins_to_cuts(x, bins, labels=labels, retbins=retbins,precision=precision,
-                         include_lowest=True)
-
+    return _bins_to_cuts(x, bins, labels=labels, retbins=retbins,
+                         precision=precision, include_lowest=True)
 
 
 def _bins_to_cuts(x, bins, right=True, labels=None, retbins=False,
@@ -191,7 +196,7 @@ def _bins_to_cuts(x, bins, right=True, labels=None, retbins=False,
     if include_lowest:
         ids[x == bins[0]] = 1
 
-    na_mask = com.isnull(x) | (ids == len(bins)) | (ids == 0)
+    na_mask = isnull(x) | (ids == len(bins)) | (ids == 0)
     has_nas = na_mask.any()
 
     if labels is not False:
@@ -217,7 +222,7 @@ def _bins_to_cuts(x, bins, right=True, labels=None, retbins=False,
 
         levels = np.asarray(levels, dtype=object)
         np.putmask(ids, na_mask, 0)
-        fac = Categorical(ids - 1, levels, ordered=True, name=name, fastpath=True)
+        fac = Categorical(ids - 1, levels, ordered=True, fastpath=True)
     else:
         fac = ids - 1
         if has_nas:
@@ -225,7 +230,7 @@ def _bins_to_cuts(x, bins, right=True, labels=None, retbins=False,
             np.putmask(fac, na_mask, np.nan)
 
     if x_is_series:
-        fac = Series(fac, index=series_index)
+        fac = Series(fac, index=series_index, name=name)
 
     if not retbins:
         return fac
@@ -261,7 +266,7 @@ def _format_label(x, precision=3):
     fmt_str = '%%.%dg' % precision
     if np.isinf(x):
         return str(x)
-    elif com.is_float(x):
+    elif is_float(x):
         frac, whole = np.modf(x)
         sgn = '-' if x < 0 else ''
         whole = abs(whole)
