@@ -7,33 +7,34 @@ from pandas.core.index import Index
 from pandas.tseries.index import DatetimeIndex
 
 from pandas import Timestamp
-from pandas.tseries.offsets import generate_range
+from pandas.tseries.offsets import (BDay, BMonthEnd, CDay, MonthEnd,
+                                    generate_range, DateOffset, Minute)
 from pandas.tseries.index import cdate_range, bdate_range, date_range
 
-import pandas.core.datetools as datetools
+from pandas.core import common as com
 from pandas.util.testing import assertRaisesRegexp
 import pandas.util.testing as tm
 
 
 def eq_gen_range(kwargs, expected):
     rng = generate_range(**kwargs)
-    assert(np.array_equal(list(rng), expected))
+    assert (np.array_equal(list(rng), expected))
 
 
 START, END = datetime(2009, 1, 1), datetime(2010, 1, 1)
 
 
 class TestGenRangeGeneration(tm.TestCase):
+
     def test_generate(self):
-        rng1 = list(generate_range(START, END, offset=datetools.bday))
+        rng1 = list(generate_range(START, END, offset=BDay()))
         rng2 = list(generate_range(START, END, time_rule='B'))
-        self.assert_numpy_array_equal(rng1, rng2)
+        self.assertEqual(rng1, rng2)
 
     def test_generate_cday(self):
-        tm._skip_if_no_cday()
-        rng1 = list(generate_range(START, END, offset=datetools.cday))
+        rng1 = list(generate_range(START, END, offset=CDay()))
         rng2 = list(generate_range(START, END, time_rule='C'))
-        self.assert_numpy_array_equal(rng1, rng2)
+        self.assertEqual(rng1, rng2)
 
     def test_1(self):
         eq_gen_range(dict(start=datetime(2009, 3, 25), periods=2),
@@ -68,50 +69,51 @@ class TestGenRangeGeneration(tm.TestCase):
                                   freq='Q-DEC', tz=None)
         expected2 = DatetimeIndex(expected2_list, dtype='datetime64[ns]',
                                   freq='W-SUN', tz=None)
-        self.assertTrue(result1.equals(expected1))
-        self.assertTrue(result2.equals(expected2))
+        self.assert_index_equal(result1, expected1)
+        self.assert_index_equal(result2, expected2)
 
 
 class TestDateRange(tm.TestCase):
-
     def setUp(self):
         self.rng = bdate_range(START, END)
 
     def test_constructor(self):
-        rng = bdate_range(START, END, freq=datetools.bday)
-        rng = bdate_range(START, periods=20, freq=datetools.bday)
-        rng = bdate_range(end=START, periods=20, freq=datetools.bday)
+        bdate_range(START, END, freq=BDay())
+        bdate_range(START, periods=20, freq=BDay())
+        bdate_range(end=START, periods=20, freq=BDay())
         self.assertRaises(ValueError, date_range, '2011-1-1', '2012-1-1', 'B')
         self.assertRaises(ValueError, bdate_range, '2011-1-1', '2012-1-1', 'B')
 
     def test_naive_aware_conflicts(self):
-        naive = bdate_range(START, END, freq=datetools.bday, tz=None)
-        aware = bdate_range(START, END, freq=datetools.bday, tz="Asia/Hong_Kong")
+        naive = bdate_range(START, END, freq=BDay(), tz=None)
+        aware = bdate_range(START, END, freq=BDay(),
+                            tz="Asia/Hong_Kong")
         assertRaisesRegexp(TypeError, "tz-naive.*tz-aware", naive.join, aware)
         assertRaisesRegexp(TypeError, "tz-naive.*tz-aware", aware.join, naive)
 
     def test_cached_range(self):
-        rng = DatetimeIndex._cached_range(START, END,
-                                          offset=datetools.bday)
-        rng = DatetimeIndex._cached_range(START, periods=20,
-                                          offset=datetools.bday)
-        rng = DatetimeIndex._cached_range(end=START, periods=20,
-                                          offset=datetools.bday)
+        DatetimeIndex._cached_range(START, END, offset=BDay())
+        DatetimeIndex._cached_range(START, periods=20, offset=BDay())
+        DatetimeIndex._cached_range(end=START, periods=20, offset=BDay())
 
-        assertRaisesRegexp(TypeError, "offset", DatetimeIndex._cached_range, START, END)
+        assertRaisesRegexp(TypeError, "offset", DatetimeIndex._cached_range,
+                           START, END)
 
-        assertRaisesRegexp(TypeError, "specify period", DatetimeIndex._cached_range, START,
-                          offset=datetools.bday)
+        assertRaisesRegexp(TypeError, "specify period",
+                           DatetimeIndex._cached_range, START,
+                           offset=BDay())
 
-        assertRaisesRegexp(TypeError, "specify period", DatetimeIndex._cached_range, end=END,
-                          offset=datetools.bday)
+        assertRaisesRegexp(TypeError, "specify period",
+                           DatetimeIndex._cached_range, end=END,
+                           offset=BDay())
 
-        assertRaisesRegexp(TypeError, "start or end", DatetimeIndex._cached_range, periods=20,
-                          offset=datetools.bday)
+        assertRaisesRegexp(TypeError, "start or end",
+                           DatetimeIndex._cached_range, periods=20,
+                           offset=BDay())
 
     def test_cached_range_bug(self):
         rng = date_range('2010-09-01 05:00:00', periods=50,
-                         freq=datetools.DateOffset(hours=6))
+                         freq=DateOffset(hours=6))
         self.assertEqual(len(rng), 50)
         self.assertEqual(rng[0], datetime(2010, 9, 1, 5))
 
@@ -124,7 +126,8 @@ class TestDateRange(tm.TestCase):
 
     def test_timezone_comparaison_assert(self):
         start = Timestamp('20130220 10:00', tz='US/Eastern')
-        self.assertRaises(AssertionError, date_range, start, periods=2, tz='Europe/Berlin')
+        self.assertRaises(AssertionError, date_range, start, periods=2,
+                          tz='Europe/Berlin')
 
     def test_comparison(self):
         d = self.rng[10]
@@ -136,7 +139,7 @@ class TestDateRange(tm.TestCase):
     def test_copy(self):
         cp = self.rng.copy()
         repr(cp)
-        self.assertTrue(cp.equals(self.rng))
+        self.assert_index_equal(cp, self.rng)
 
     def test_repr(self):
         # only really care that it works
@@ -144,11 +147,13 @@ class TestDateRange(tm.TestCase):
 
     def test_getitem(self):
         smaller = self.rng[:5]
-        self.assert_numpy_array_equal(smaller, self.rng.view(np.ndarray)[:5])
+        exp = DatetimeIndex(self.rng.view(np.ndarray)[:5])
+        self.assert_index_equal(smaller, exp)
+
         self.assertEqual(smaller.offset, self.rng.offset)
 
         sliced = self.rng[::5]
-        self.assertEqual(sliced.offset, datetools.bday * 5)
+        self.assertEqual(sliced.offset, BDay() * 5)
 
         fancy_indexed = self.rng[[4, 3, 2, 1, 0]]
         self.assertEqual(len(fancy_indexed), 5)
@@ -176,9 +181,9 @@ class TestDateRange(tm.TestCase):
         self.assertEqual(shifted[0], self.rng[0])
         self.assertEqual(shifted.offset, self.rng.offset)
 
-        rng = date_range(START, END, freq=datetools.bmonthEnd)
-        shifted = rng.shift(1, freq=datetools.bday)
-        self.assertEqual(shifted[0], rng[0] + datetools.bday)
+        rng = date_range(START, END, freq=BMonthEnd())
+        shifted = rng.shift(1, freq=BDay())
+        self.assertEqual(shifted[0], rng[0] + BDay())
 
     def test_pickle_unpickle(self):
         unpickled = self.round_trip_pickle(self.rng)
@@ -207,10 +212,10 @@ class TestDateRange(tm.TestCase):
         tm.assertIsInstance(the_union, DatetimeIndex)
 
         # order does not matter
-        self.assert_numpy_array_equal(right.union(left), the_union)
+        tm.assert_index_equal(right.union(left), the_union)
 
         # overlapping, but different offset
-        rng = date_range(START, END, freq=datetools.bmonthEnd)
+        rng = date_range(START, END, freq=BMonthEnd())
 
         the_union = self.rng.union(rng)
         tm.assertIsInstance(the_union, DatetimeIndex)
@@ -241,49 +246,49 @@ class TestDateRange(tm.TestCase):
         tm.assertIsInstance(the_join, DatetimeIndex)
 
         # overlapping, but different offset
-        rng = date_range(START, END, freq=datetools.bmonthEnd)
+        rng = date_range(START, END, freq=BMonthEnd())
 
         the_join = self.rng.join(rng, how='outer')
         tm.assertIsInstance(the_join, DatetimeIndex)
         self.assertIsNone(the_join.freq)
 
     def test_union_not_cacheable(self):
-        rng = date_range('1/1/2000', periods=50, freq=datetools.Minute())
+        rng = date_range('1/1/2000', periods=50, freq=Minute())
         rng1 = rng[10:]
         rng2 = rng[:25]
         the_union = rng1.union(rng2)
-        self.assertTrue(the_union.equals(rng))
+        self.assert_index_equal(the_union, rng)
 
         rng1 = rng[10:]
         rng2 = rng[15:35]
         the_union = rng1.union(rng2)
         expected = rng[10:]
-        self.assertTrue(the_union.equals(expected))
+        self.assert_index_equal(the_union, expected)
 
     def test_intersection(self):
-        rng = date_range('1/1/2000', periods=50, freq=datetools.Minute())
+        rng = date_range('1/1/2000', periods=50, freq=Minute())
         rng1 = rng[10:]
         rng2 = rng[:25]
         the_int = rng1.intersection(rng2)
         expected = rng[10:25]
-        self.assertTrue(the_int.equals(expected))
+        self.assert_index_equal(the_int, expected)
         tm.assertIsInstance(the_int, DatetimeIndex)
         self.assertEqual(the_int.offset, rng.offset)
 
         the_int = rng1.intersection(rng2.view(DatetimeIndex))
-        self.assertTrue(the_int.equals(expected))
+        self.assert_index_equal(the_int, expected)
 
         # non-overlapping
         the_int = rng[:10].intersection(rng[10:])
         expected = DatetimeIndex([])
-        self.assertTrue(the_int.equals(expected))
+        self.assert_index_equal(the_int, expected)
 
     def test_intersection_bug(self):
         # GH #771
         a = bdate_range('11/30/2011', '12/31/2011')
         b = bdate_range('12/10/2011', '12/20/2011')
         result = a.intersection(b)
-        self.assertTrue(result.equals(b))
+        self.assert_index_equal(result, b)
 
     def test_summary(self):
         self.rng.summary()
@@ -302,7 +307,7 @@ class TestDateRange(tm.TestCase):
     def test_misc(self):
         end = datetime(2009, 5, 13)
         dr = bdate_range(end=end, periods=20)
-        firstDate = end - 19 * datetools.bday
+        firstDate = end - 19 * BDay()
 
         assert len(dr) == 20
         assert dr[0] == firstDate
@@ -344,23 +349,23 @@ class TestDateRange(tm.TestCase):
         # GH #456
         rng1 = bdate_range('12/5/2011', '12/5/2011')
         rng2 = bdate_range('12/2/2011', '12/5/2011')
-        rng2.offset = datetools.BDay()
+        rng2.offset = BDay()
 
         result = rng1.union(rng2)
         tm.assertIsInstance(result, DatetimeIndex)
 
     def test_error_with_zero_monthends(self):
         self.assertRaises(ValueError, date_range, '1/1/2000', '1/1/2001',
-                          freq=datetools.MonthEnd(0))
+                          freq=MonthEnd(0))
 
     def test_range_bug(self):
         # GH #770
-        offset = datetools.DateOffset(months=3)
+        offset = DateOffset(months=3)
         result = date_range("2011-1-1", "2012-1-31", freq=offset)
 
         start = datetime(2011, 1, 1)
         exp_values = [start + i * offset for i in range(5)]
-        self.assert_numpy_array_equal(result, DatetimeIndex(exp_values))
+        tm.assert_index_equal(result, DatetimeIndex(exp_values))
 
     def test_range_tz_pytz(self):
         # GH 2906
@@ -399,17 +404,18 @@ class TestDateRange(tm.TestCase):
             dr = date_range(start, end, freq='D')
             self.assertEqual(dr[0], start)
             self.assertEqual(dr[-1], end)
-            self.assertEqual(np.all(dr.hour==0), True)
+            self.assertEqual(np.all(dr.hour == 0), True)
 
             dr = date_range(start, end, freq='D', tz='US/Eastern')
             self.assertEqual(dr[0], start)
             self.assertEqual(dr[-1], end)
-            self.assertEqual(np.all(dr.hour==0), True)
+            self.assertEqual(np.all(dr.hour == 0), True)
 
-            dr = date_range(start.replace(tzinfo=None), end.replace(tzinfo=None), freq='D', tz='US/Eastern')
+            dr = date_range(start.replace(tzinfo=None), end.replace(
+                tzinfo=None), freq='D', tz='US/Eastern')
             self.assertEqual(dr[0], start)
             self.assertEqual(dr[-1], end)
-            self.assertEqual(np.all(dr.hour==0), True)
+            self.assertEqual(np.all(dr.hour == 0), True)
 
     def test_range_tz_dateutil(self):
         # GH 2906
@@ -447,8 +453,10 @@ class TestDateRange(tm.TestCase):
         late_start = datetime(2011, 3, 1)
         late_end = datetime(2011, 5, 1)
 
-        early_dr = date_range(start=early_start, end=early_end, tz=tz, freq=datetools.monthEnd)
-        late_dr = date_range(start=late_start, end=late_end, tz=tz, freq=datetools.monthEnd)
+        early_dr = date_range(start=early_start, end=early_end, tz=tz,
+                              freq=MonthEnd())
+        late_dr = date_range(start=late_start, end=late_end, tz=tz,
+                             freq=MonthEnd())
 
         early_dr.union(late_dr)
 
@@ -464,8 +472,10 @@ class TestDateRange(tm.TestCase):
         late_start = datetime(2011, 3, 1)
         late_end = datetime(2011, 5, 1)
 
-        early_dr = date_range(start=early_start, end=early_end, tz=tz, freq=datetools.monthEnd)
-        late_dr = date_range(start=late_start, end=late_end, tz=tz, freq=datetools.monthEnd)
+        early_dr = date_range(start=early_start, end=early_end, tz=tz,
+                              freq=MonthEnd())
+        late_dr = date_range(start=late_start, end=late_end, tz=tz,
+                             freq=MonthEnd())
 
         early_dr.union(late_dr)
 
@@ -473,16 +483,86 @@ class TestDateRange(tm.TestCase):
         begin = datetime(2011, 1, 1)
         end = datetime(2014, 1, 1)
 
-        for freq in ["3D", "2M", "7W", "3H", "A"]:
+        for freq in ["1D", "3D", "2M", "7W", "3H", "A"]:
             closed = date_range(begin, end, closed=None, freq=freq)
             left = date_range(begin, end, closed="left", freq=freq)
             right = date_range(begin, end, closed="right", freq=freq)
+            expected_left = left
+            expected_right = right
 
-            expected_left = closed[:-1]
-            expected_right = closed[1:]
+            if end == closed[-1]:
+                expected_left = closed[:-1]
+            if begin == closed[0]:
+                expected_right = closed[1:]
 
-            self.assertTrue(expected_left.equals(left))
-            self.assertTrue(expected_right.equals(right))
+            self.assert_index_equal(expected_left, left)
+            self.assert_index_equal(expected_right, right)
+
+    def test_range_closed_with_tz_aware_start_end(self):
+        # GH12409, GH12684
+        begin = Timestamp('2011/1/1', tz='US/Eastern')
+        end = Timestamp('2014/1/1', tz='US/Eastern')
+
+        for freq in ["1D", "3D", "2M", "7W", "3H", "A"]:
+            closed = date_range(begin, end, closed=None, freq=freq)
+            left = date_range(begin, end, closed="left", freq=freq)
+            right = date_range(begin, end, closed="right", freq=freq)
+            expected_left = left
+            expected_right = right
+
+            if end == closed[-1]:
+                expected_left = closed[:-1]
+            if begin == closed[0]:
+                expected_right = closed[1:]
+
+            self.assert_index_equal(expected_left, left)
+            self.assert_index_equal(expected_right, right)
+
+        begin = Timestamp('2011/1/1')
+        end = Timestamp('2014/1/1')
+        begintz = Timestamp('2011/1/1', tz='US/Eastern')
+        endtz = Timestamp('2014/1/1', tz='US/Eastern')
+
+        for freq in ["1D", "3D", "2M", "7W", "3H", "A"]:
+            closed = date_range(begin, end, closed=None, freq=freq,
+                                tz='US/Eastern')
+            left = date_range(begin, end, closed="left", freq=freq,
+                              tz='US/Eastern')
+            right = date_range(begin, end, closed="right", freq=freq,
+                               tz='US/Eastern')
+            expected_left = left
+            expected_right = right
+
+            if endtz == closed[-1]:
+                expected_left = closed[:-1]
+            if begintz == closed[0]:
+                expected_right = closed[1:]
+
+            self.assert_index_equal(expected_left, left)
+            self.assert_index_equal(expected_right, right)
+
+    def test_range_closed_boundary(self):
+        # GH 11804
+        for closed in ['right', 'left', None]:
+            right_boundary = date_range('2015-09-12', '2015-12-01',
+                                        freq='QS-MAR', closed=closed)
+            left_boundary = date_range('2015-09-01', '2015-09-12',
+                                       freq='QS-MAR', closed=closed)
+            both_boundary = date_range('2015-09-01', '2015-12-01',
+                                       freq='QS-MAR', closed=closed)
+            expected_right = expected_left = expected_both = both_boundary
+
+            if closed == 'right':
+                expected_left = both_boundary[1:]
+            if closed == 'left':
+                expected_right = both_boundary[:-1]
+            if closed is None:
+                expected_right = both_boundary[1:]
+                expected_left = both_boundary[:-1]
+
+            self.assert_index_equal(right_boundary, expected_right)
+            self.assert_index_equal(left_boundary, expected_left)
+            self.assert_index_equal(both_boundary, expected_both)
 
     def test_years_only(self):
         # GH 6961
@@ -496,44 +576,46 @@ class TestDateRange(tm.TestCase):
                               freq='345min')
         result_2 = date_range('2005-01-13 10:00', '2005-01-13 16:00',
                               freq='345min')
-        expected_1 = DatetimeIndex(['2005-01-12 10:00:00', '2005-01-12 15:45:00'],
-                                   dtype='datetime64[ns]', freq='345T', tz=None)
-        expected_2 = DatetimeIndex(['2005-01-13 10:00:00', '2005-01-13 15:45:00'],
-                                   dtype='datetime64[ns]', freq='345T', tz=None)
-        self.assertTrue(result_1.equals(expected_1))
-        self.assertTrue(result_2.equals(expected_2))
+        expected_1 = DatetimeIndex(['2005-01-12 10:00:00',
+                                    '2005-01-12 15:45:00'],
+                                   dtype='datetime64[ns]', freq='345T',
+                                   tz=None)
+        expected_2 = DatetimeIndex(['2005-01-13 10:00:00',
+                                    '2005-01-13 15:45:00'],
+                                   dtype='datetime64[ns]', freq='345T',
+                                   tz=None)
+        self.assert_index_equal(result_1, expected_1)
+        self.assert_index_equal(result_2, expected_2)
+
 
 class TestCustomDateRange(tm.TestCase):
-
     def setUp(self):
-        tm._skip_if_no_cday()
         self.rng = cdate_range(START, END)
 
     def test_constructor(self):
-        rng = cdate_range(START, END, freq=datetools.cday)
-        rng = cdate_range(START, periods=20, freq=datetools.cday)
-        rng = cdate_range(end=START, periods=20, freq=datetools.cday)
+        cdate_range(START, END, freq=CDay())
+        cdate_range(START, periods=20, freq=CDay())
+        cdate_range(end=START, periods=20, freq=CDay())
         self.assertRaises(ValueError, date_range, '2011-1-1', '2012-1-1', 'C')
         self.assertRaises(ValueError, cdate_range, '2011-1-1', '2012-1-1', 'C')
 
     def test_cached_range(self):
-        rng = DatetimeIndex._cached_range(START, END,
-                                          offset=datetools.cday)
-        rng = DatetimeIndex._cached_range(START, periods=20,
-                                          offset=datetools.cday)
-        rng = DatetimeIndex._cached_range(end=START, periods=20,
-                                          offset=datetools.cday)
+        DatetimeIndex._cached_range(START, END, offset=CDay())
+        DatetimeIndex._cached_range(START, periods=20,
+                                    offset=CDay())
+        DatetimeIndex._cached_range(end=START, periods=20,
+                                    offset=CDay())
 
         self.assertRaises(Exception, DatetimeIndex._cached_range, START, END)
 
         self.assertRaises(Exception, DatetimeIndex._cached_range, START,
-                          freq=datetools.cday)
+                          freq=CDay())
 
         self.assertRaises(Exception, DatetimeIndex._cached_range, end=END,
-                          freq=datetools.cday)
+                          freq=CDay())
 
         self.assertRaises(Exception, DatetimeIndex._cached_range, periods=20,
-                          freq=datetools.cday)
+                          freq=CDay())
 
     def test_comparison(self):
         d = self.rng[10]
@@ -545,7 +627,7 @@ class TestCustomDateRange(tm.TestCase):
     def test_copy(self):
         cp = self.rng.copy()
         repr(cp)
-        self.assertTrue(cp.equals(self.rng))
+        self.assert_index_equal(cp, self.rng)
 
     def test_repr(self):
         # only really care that it works
@@ -553,11 +635,12 @@ class TestCustomDateRange(tm.TestCase):
 
     def test_getitem(self):
         smaller = self.rng[:5]
-        self.assert_numpy_array_equal(smaller, self.rng.view(np.ndarray)[:5])
+        exp = DatetimeIndex(self.rng.view(np.ndarray)[:5])
+        self.assert_index_equal(smaller, exp)
         self.assertEqual(smaller.offset, self.rng.offset)
 
         sliced = self.rng[::5]
-        self.assertEqual(sliced.offset, datetools.cday * 5)
+        self.assertEqual(sliced.offset, CDay() * 5)
 
         fancy_indexed = self.rng[[4, 3, 2, 1, 0]]
         self.assertEqual(len(fancy_indexed), 5)
@@ -573,6 +656,7 @@ class TestCustomDateRange(tm.TestCase):
         self.assert_numpy_array_equal(values, expected)
 
     def test_shift(self):
+
         shifted = self.rng.shift(5)
         self.assertEqual(shifted[0], self.rng[5])
         self.assertEqual(shifted.offset, self.rng.offset)
@@ -585,9 +669,10 @@ class TestCustomDateRange(tm.TestCase):
         self.assertEqual(shifted[0], self.rng[0])
         self.assertEqual(shifted.offset, self.rng.offset)
 
-        rng = date_range(START, END, freq=datetools.bmonthEnd)
-        shifted = rng.shift(1, freq=datetools.cday)
-        self.assertEqual(shifted[0], rng[0] + datetools.cday)
+        with tm.assert_produces_warning(com.PerformanceWarning):
+            rng = date_range(START, END, freq=BMonthEnd())
+            shifted = rng.shift(1, freq=CDay())
+            self.assertEqual(shifted[0], rng[0] + CDay())
 
     def test_pickle_unpickle(self):
         unpickled = self.round_trip_pickle(self.rng)
@@ -616,10 +701,10 @@ class TestCustomDateRange(tm.TestCase):
         tm.assertIsInstance(the_union, DatetimeIndex)
 
         # order does not matter
-        self.assert_numpy_array_equal(right.union(left), the_union)
+        self.assert_index_equal(right.union(left), the_union)
 
         # overlapping, but different offset
-        rng = date_range(START, END, freq=datetools.bmonthEnd)
+        rng = date_range(START, END, freq=BMonthEnd())
 
         the_union = self.rng.union(rng)
         tm.assertIsInstance(the_union, DatetimeIndex)
@@ -650,7 +735,7 @@ class TestCustomDateRange(tm.TestCase):
         tm.assertIsInstance(the_join, DatetimeIndex)
 
         # overlapping, but different offset
-        rng = date_range(START, END, freq=datetools.bmonthEnd)
+        rng = date_range(START, END, freq=BMonthEnd())
 
         the_join = self.rng.join(rng, how='outer')
         tm.assertIsInstance(the_join, DatetimeIndex)
@@ -661,7 +746,7 @@ class TestCustomDateRange(tm.TestCase):
         a = cdate_range('11/30/2011', '12/31/2011')
         b = cdate_range('12/10/2011', '12/20/2011')
         result = a.intersection(b)
-        self.assertTrue(result.equals(b))
+        self.assert_index_equal(result, b)
 
     def test_summary(self):
         self.rng.summary()
@@ -680,7 +765,7 @@ class TestCustomDateRange(tm.TestCase):
     def test_misc(self):
         end = datetime(2009, 5, 13)
         dr = cdate_range(end=end, periods=20)
-        firstDate = end - 19 * datetools.cday
+        firstDate = end - 19 * CDay()
 
         assert len(dr) == 20
         assert dr[0] == firstDate
@@ -705,7 +790,7 @@ class TestCustomDateRange(tm.TestCase):
         # GH #456
         rng1 = cdate_range('12/5/2011', '12/5/2011')
         rng2 = cdate_range('12/2/2011', '12/5/2011')
-        rng2.offset = datetools.CDay()
+        rng2.offset = CDay()
 
         result = rng1.union(rng2)
         tm.assertIsInstance(result, DatetimeIndex)
@@ -713,26 +798,25 @@ class TestCustomDateRange(tm.TestCase):
     def test_cdaterange(self):
         rng = cdate_range('2013-05-01', periods=3)
         xp = DatetimeIndex(['2013-05-01', '2013-05-02', '2013-05-03'])
-        self.assertTrue(xp.equals(rng))
+        self.assert_index_equal(xp, rng)
 
     def test_cdaterange_weekmask(self):
         rng = cdate_range('2013-05-01', periods=3,
                           weekmask='Sun Mon Tue Wed Thu')
         xp = DatetimeIndex(['2013-05-01', '2013-05-02', '2013-05-05'])
-        self.assertTrue(xp.equals(rng))
+        self.assert_index_equal(xp, rng)
 
     def test_cdaterange_holidays(self):
-        rng = cdate_range('2013-05-01', periods=3,
-                          holidays=['2013-05-01'])
+        rng = cdate_range('2013-05-01', periods=3, holidays=['2013-05-01'])
         xp = DatetimeIndex(['2013-05-02', '2013-05-03', '2013-05-06'])
-        self.assertTrue(xp.equals(rng))
+        self.assert_index_equal(xp, rng)
 
     def test_cdaterange_weekmask_and_holidays(self):
         rng = cdate_range('2013-05-01', periods=3,
                           weekmask='Sun Mon Tue Wed Thu',
                           holidays=['2013-05-01'])
         xp = DatetimeIndex(['2013-05-02', '2013-05-05', '2013-05-06'])
-        self.assertTrue(xp.equals(rng))
+        self.assert_index_equal(xp, rng)
 
 
 if __name__ == '__main__':
