@@ -1,7 +1,7 @@
 from vbench.api import Benchmark
 from datetime import datetime
 
-common_setup = """from pandas_vb_common import *
+common_setup = """from .pandas_vb_common import *
 """
 
 #----------------------------------------------------------------------
@@ -98,11 +98,11 @@ def g():
         pass
 
 def h():
-    for i in xrange(10000):
+    for i in range(10000):
         df2['A']
 
 def j():
-    for i in xrange(10000):
+    for i in range(10000):
         df3[0]
 
 """
@@ -126,8 +126,8 @@ frame_getitem_single_column2 = Benchmark('j()', setup,
 setup = common_setup + """
 idx = date_range('1/1/2000', periods=100000, freq='D')
 df = DataFrame(randn(100000, 1),columns=['A'],index=idx)
-def f(x):
-    x = x.copy()
+def f(df):
+    x = df.copy()
     x['date'] = x.index
 """
 
@@ -290,31 +290,76 @@ frame_isnull  = Benchmark('isnull(df)', setup,
                            start_date=datetime(2012,1,1))
 
 ## dropna
-setup = common_setup + """
+dropna_setup = common_setup + """
 data = np.random.randn(10000, 1000)
 df = DataFrame(data)
 df.ix[50:1000,20:50] = np.nan
 df.ix[2000:3000] = np.nan
 df.ix[:,60:70] = np.nan
 """
-frame_dropna_axis0_any  = Benchmark('df.dropna(how="any",axis=0)', setup,
+frame_dropna_axis0_any  = Benchmark('df.dropna(how="any",axis=0)', dropna_setup,
                                      start_date=datetime(2012,1,1))
-frame_dropna_axis0_all  = Benchmark('df.dropna(how="all",axis=0)', setup,
+frame_dropna_axis0_all  = Benchmark('df.dropna(how="all",axis=0)', dropna_setup,
                                      start_date=datetime(2012,1,1))
 
-setup = common_setup + """
+frame_dropna_axis1_any  = Benchmark('df.dropna(how="any",axis=1)', dropna_setup,
+                                    start_date=datetime(2012,1,1))
+
+frame_dropna_axis1_all  = Benchmark('df.dropna(how="all",axis=1)', dropna_setup,
+                                    start_date=datetime(2012,1,1))
+
+# dropna on mixed dtypes
+dropna_mixed_setup = common_setup + """
 data = np.random.randn(10000, 1000)
 df = DataFrame(data)
 df.ix[50:1000,20:50] = np.nan
 df.ix[2000:3000] = np.nan
 df.ix[:,60:70] = np.nan
+df['foo'] = 'bar'
 """
-frame_dropna_axis1_any  = Benchmark('df.dropna(how="any",axis=1)', setup,
-                                    start_date=datetime(2012,1,1))
+frame_dropna_axis0_any_mixed_dtypes  = Benchmark('df.dropna(how="any",axis=0)', dropna_mixed_setup,
+                                                 start_date=datetime(2012,1,1))
+frame_dropna_axis0_all_mixed_dtypes  = Benchmark('df.dropna(how="all",axis=0)', dropna_mixed_setup,
+                                                 start_date=datetime(2012,1,1))
 
-frame_dropna_axis1_all  = Benchmark('df.dropna(how="all",axis=1)', setup,
-                                    start_date=datetime(2012,1,1))
+frame_dropna_axis1_any_mixed_dtypes  = Benchmark('df.dropna(how="any",axis=1)', dropna_mixed_setup,
+                                                 start_date=datetime(2012,1,1))
 
+frame_dropna_axis1_all_mixed_dtypes  = Benchmark('df.dropna(how="all",axis=1)', dropna_mixed_setup,
+                                                 start_date=datetime(2012,1,1))
+
+## dropna multi
+dropna_setup = common_setup + """
+data = np.random.randn(10000, 1000)
+df = DataFrame(data)
+df.ix[50:1000,20:50] = np.nan
+df.ix[2000:3000] = np.nan
+df.ix[:,60:70] = np.nan
+df.index = MultiIndex.from_tuples(df.index.map(lambda x: (x, x)))
+df.columns = MultiIndex.from_tuples(df.columns.map(lambda x: (x, x)))
+"""
+frame_count_level_axis0_multi = Benchmark('df.count(axis=0, level=1)', dropna_setup,
+                                          start_date=datetime(2012,1,1))
+
+frame_count_level_axis1_multi = Benchmark('df.count(axis=1, level=1)', dropna_setup,
+                                          start_date=datetime(2012,1,1))
+
+# dropna on mixed dtypes
+dropna_mixed_setup = common_setup + """
+data = np.random.randn(10000, 1000)
+df = DataFrame(data)
+df.ix[50:1000,20:50] = np.nan
+df.ix[2000:3000] = np.nan
+df.ix[:,60:70] = np.nan
+df['foo'] = 'bar'
+df.index = MultiIndex.from_tuples(df.index.map(lambda x: (x, x)))
+df.columns = MultiIndex.from_tuples(df.columns.map(lambda x: (x, x)))
+"""
+frame_count_level_axis0_mixed_dtypes_multi  = Benchmark('df.count(axis=0, level=1)', dropna_mixed_setup,
+                                                        start_date=datetime(2012,1,1))
+
+frame_count_level_axis1_mixed_dtypes_multi  = Benchmark('df.count(axis=1, level=1)', dropna_mixed_setup,
+                                                        start_date=datetime(2012,1,1))
 
 #----------------------------------------------------------------------
 # apply
@@ -373,8 +418,8 @@ frame_dtypes = Benchmark('df.dtypes', setup,
 #----------------------------------------------------------------------
 # equals
 setup = common_setup + """
-def make_pair(name):
-    df = globals()[name]
+def make_pair(frame):
+    df = frame
     df2 = df.copy()
     df2.ix[-1,-1] = np.nan
     return df, df2
@@ -392,8 +437,8 @@ object_df = DataFrame([['foo']*1000]*1000)
 nonunique_cols = object_df.copy()
 nonunique_cols.columns = ['A']*len(nonunique_cols.columns)
 
-pairs = dict([(name,make_pair(name))
-         for name in ('float_df', 'object_df', 'nonunique_cols')])
+pairs = dict([(name, make_pair(frame))
+         for name, frame in (('float_df', float_df), ('object_df', object_df), ('nonunique_cols', nonunique_cols))])
 """
 frame_float_equal = Benchmark('test_equal("float_df")', setup)
 frame_object_equal = Benchmark('test_equal("object_df")', setup)
@@ -449,15 +494,32 @@ frame_shift_axis1 = Benchmark('df.shift(1,axis=1)', setup,
 
 setup = common_setup + """
 def get_data(n=100000):
-    return ((x, x*20, x*100) for x in xrange(n))
+    return ((x, x*20, x*100) for x in range(n))
 """
 
 frame_from_records_generator = Benchmark('df = DataFrame.from_records(get_data())',
                                 setup,
                                 name='frame_from_records_generator',
-                                start_date=datetime(2013,10,04))  # issue-4911
+                                start_date=datetime(2013,10,4))  # issue-4911
 
 frame_from_records_generator_nrows = Benchmark('df = DataFrame.from_records(get_data(), nrows=1000)',
                                 setup,
                                 name='frame_from_records_generator_nrows',
                                 start_date=datetime(2013,10,04))  # issue-4911
+
+#-----------------------------------------------------------------------------
+# duplicated
+
+setup = common_setup + '''
+n = 1 << 20
+
+t = date_range('2015-01-01', freq='S', periods=n // 64)
+xs = np.random.randn(n // 64).round(2)
+
+df = DataFrame({'a':np.random.randint(- 1 << 8, 1 << 8, n),
+                'b':np.random.choice(t, n),
+                'c':np.random.choice(xs, n)})
+'''
+
+frame_duplicated = Benchmark('df.duplicated()', setup,
+                             name='frame_duplicated')
