@@ -3,7 +3,7 @@ from datetime import datetime
 
 start_date = datetime(2012, 7, 1)
 
-common_setup = """from pandas_vb_common import *
+common_setup = """from .pandas_vb_common import *
 import os
 
 f = '__test__.h5'
@@ -19,7 +19,7 @@ def remove(f):
 # get from a store
 
 setup1 = common_setup + """
-index = [rands(10) for _ in xrange(25000)]
+index = tm.makeStringIndex(25000)
 df = DataFrame({'float1' : randn(25000),
                 'float2' : randn(25000)},
                index=index)
@@ -36,7 +36,7 @@ read_store = Benchmark("store.get('df1')", setup1, cleanup="store.close()",
 # write to a store
 
 setup2 = common_setup + """
-index = [rands(10) for _ in xrange(25000)]
+index = tm.makeStringIndex(25000)
 df = DataFrame({'float1' : randn(25000),
                 'float2' : randn(25000)},
                index=index)
@@ -52,7 +52,7 @@ write_store = Benchmark(
 # get from a store (mixed)
 
 setup3 = common_setup + """
-index = [rands(10) for _ in xrange(25000)]
+index = tm.makeStringIndex(25000)
 df = DataFrame({'float1' : randn(25000),
                 'float2' : randn(25000),
                 'string1' : ['foo'] * 25000,
@@ -73,7 +73,7 @@ read_store_mixed = Benchmark(
 # write to a store (mixed)
 
 setup4 = common_setup + """
-index = [rands(10) for _ in xrange(25000)]
+index = tm.makeStringIndex(25000)
 df = DataFrame({'float1' : randn(25000),
                 'float2' : randn(25000),
                 'string1' : ['foo'] * 25000,
@@ -93,7 +93,7 @@ write_store_mixed = Benchmark(
 
 setup5 = common_setup + """
 N=10000
-index = [rands(10) for _ in xrange(N)]
+index = tm.makeStringIndex(N)
 df = DataFrame({'float1' : randn(N),
                 'float2' : randn(N),
                 'string1' : ['foo'] * N,
@@ -115,7 +115,7 @@ read_store_table_mixed = Benchmark(
 # write to a table (mixed)
 
 setup6 = common_setup + """
-index = [rands(10) for _ in xrange(25000)]
+index = tm.makeStringIndex(25000)
 df = DataFrame({'float1' : randn(25000),
                 'float2' : randn(25000),
                 'string1' : ['foo'] * 25000,
@@ -134,7 +134,7 @@ write_store_table_mixed = Benchmark(
 # select from a table
 
 setup7 = common_setup + """
-index = [rands(10) for _ in xrange(25000)]
+index = tm.makeStringIndex(25000)
 df = DataFrame({'float1' : randn(25000),
                 'float2' : randn(25000) },
                index=index)
@@ -153,7 +153,7 @@ read_store_table = Benchmark(
 # write to a table
 
 setup8 = common_setup + """
-index = [rands(10) for _ in xrange(25000)]
+index = tm.makeStringIndex(25000)
 df = DataFrame({'float1' : randn(25000),
                 'float2' : randn(25000) },
                index=index)
@@ -234,8 +234,8 @@ query_store_table = Benchmark(
 # select from a panel table
 
 setup13 = common_setup + """
-p = Panel(randn(20, 1000, 25), items= [ 'Item%03d' % i for i in xrange(20) ],
-                   major_axis=date_range('1/1/2000', periods=1000), minor_axis = [ 'E%03d' % i for i in xrange(25) ])
+p = Panel(randn(20, 1000, 25), items= [ 'Item%03d' % i for i in range(20) ],
+                   major_axis=date_range('1/1/2000', periods=1000), minor_axis = [ 'E%03d' % i for i in range(25) ])
 
 remove(f)
 store = HDFStore(f)
@@ -251,8 +251,8 @@ read_store_table_panel = Benchmark(
 # write to a panel table
 
 setup14 = common_setup + """
-p = Panel(randn(20, 1000, 25), items= [ 'Item%03d' % i for i in xrange(20) ],
-                   major_axis=date_range('1/1/2000', periods=1000), minor_axis = [ 'E%03d' % i for i in xrange(25) ])
+p = Panel(randn(20, 1000, 25), items= [ 'Item%03d' % i for i in range(20) ],
+                   major_axis=date_range('1/1/2000', periods=1000), minor_axis = [ 'E%03d' % i for i in range(25) ])
 
 remove(f)
 store = HDFStore(f)
@@ -266,7 +266,7 @@ write_store_table_panel = Benchmark(
 # write to a table (data_columns)
 
 setup15 = common_setup + """
-df = DataFrame(np.random.randn(10000,10),columns = [ 'C%03d' % i for i in xrange(10) ])
+df = DataFrame(np.random.randn(10000,10),columns = [ 'C%03d' % i for i in range(10) ])
 
 remove(f)
 store = HDFStore(f)
